@@ -1404,6 +1404,40 @@ class WinOSClient:
         result = self.run_ps_local(cmd)
         return result.ok
 
+    def get_volumes(self) -> list[dict]:
+        """Get virtual volumes info"""
+
+        disks = self.run_ps('Get-Volume | ConvertTo-Json').json()
+
+        result = [
+            {
+                'DriveLetter': disk['DriveLetter'],
+                'FileSystemLabel': disk['FileSystemLabel'],
+                'Size': int(disk['Size']),
+                'SizeRemaining': int(disk['SizeRemaining']),
+                'HealthStatus': disk['HealthStatus'],
+                'DriveType': disk['DriveType'],
+                'FileSystem': disk['FileSystem'],
+                'DedupMode': disk['DedupMode'],
+                'AllocationUnitSize': disk['AllocationUnitSize'],
+                'OperationalStatus': disk['OperationalStatus'],
+                'UniqueId': disk['UniqueId'],
+
+            } for disk in disks
+        ]
+
+        return result
+
+    def get_volumes_count(self) -> int:
+        """Count initialized volumes.
+
+        Note: CD-ROMs and System Reserved volumes included.
+
+        :return:
+        """
+
+        return len(self.get_volumes())
+
     # ---------------- NEED REFACTORING ------------------
     def attach_share(self, share, username, password):
         """Attach network share"""
